From 871a37e53525c2a2d1d3eda0ff300dec5e6a9ea0 Mon Sep 17 00:00:00 2001
From: EndrII <EndrIIMail@gmail.com>
Date: Fri, 2 Jul 2021 16:59:45 +0300
Subject: [PATCH] cqtdeployer v 1.5.2.4

---
 Deploy/Deploy.pro                                 | 2 +-
 Deploy/configparser.cpp                           | 2 +-
 Deploy/deploycore.cpp                             | 4 ++--
 Deploy/deploycore.h                               | 4 ++--
 Deploy/extracter.cpp                              | 2 +-
 QIFData/config/configLinux.xml                    | 2 +-
 QIFData/config/configWin.xml                      | 2 +-
 QIFData/installerCQtDeployer.pri                  | 2 +-
 QIFData/packages/cqtdeployer.1_5/meta/package.xml | 2 +-
 snap/gui/cqtdeployer.desktop                      | 4 ++--
 snap/snapcraft.yaml                               | 2 +-
 11 files changed, 14 insertions(+), 14 deletions(-)

diff --git a/Deploy/Deploy.pro b/Deploy/Deploy.pro
index 599a2ad..46091ab 100644
--- a/Deploy/Deploy.pro
+++ b/Deploy/Deploy.pro
@@ -19,7 +19,7 @@ TEMPLATE = lib
 
 DEFINES += DEPLOY_LIBRARY
 
-VERSION = 1.5.2.3
+VERSION = 1.5.2.4
 
 DEFINES += APP_VERSION='\\"$$VERSION\\"'
 
diff --git a/Deploy/configparser.cpp b/Deploy/configparser.cpp
index 34028aa..bfd3d67 100644
--- a/Deploy/configparser.cpp
+++ b/Deploy/configparser.cpp
@@ -833,7 +833,7 @@ bool ConfigParser::setTargets(const QStringList &value) {
     bool isfillList = false;
 
     for (const auto &i : value) {
-        QFileInfo targetInfo = DeployCore::findFile(i);
+        QFileInfo targetInfo = DeployCore::findItem(i);
 
         if (i.isEmpty())
             continue;
diff --git a/Deploy/deploycore.cpp b/Deploy/deploycore.cpp
index 056d706..c885f45 100644
--- a/Deploy/deploycore.cpp
+++ b/Deploy/deploycore.cpp
@@ -773,14 +773,14 @@ void DeployCore::printInternalError(const char * function, const char* file, int
                                 QuasarAppUtils::Error);
 }
 
-QFileInfo DeployCore::findFile(const QString &bin) {
+QFileInfo DeployCore::findItem(const QString &bin) {
     auto prefixes = QuasarAppUtils::Params::getArg("binPrefix").
             split(DeployCore::getSeparator(0), splitbehavior);
 
     for (const QString& prefix :qAsConst(prefixes)) {
         QFileInfo info(prefix + "/" + bin);
 
-        if (info.isFile()) {
+        if (info.exists()) {
             return info;
         }
     }
diff --git a/Deploy/extracter.cpp b/Deploy/extracter.cpp
index cf6ba72..1ccc164 100644
--- a/Deploy/extracter.cpp
+++ b/Deploy/extracter.cpp
@@ -113,7 +113,7 @@ void Extracter::extractExtraDataTargets() {
         const auto extraData = i.value().extraData();
         for (const auto &target : extraData) {
 
-            QFileInfo info = DeployCore::findFile(target);
+            QFileInfo info = DeployCore::findItem(target);
             if (!info.exists()) {
                 QuasarAppUtils::Params::log("Failed to copy extra data from: " + target +
                                             " Error: target not exists!.", QuasarAppUtils::Warning);
diff --git a/QIFData/config/configLinux.xml b/QIFData/config/configLinux.xml
index 05a6e18..3b8c0ef 100644
--- a/QIFData/config/configLinux.xml
+++ b/QIFData/config/configLinux.xml
@@ -3,7 +3,7 @@
     <WizardDefaultWidth>640px</WizardDefaultWidth>
     <WizardDefaultHeight>400px</WizardDefaultHeight>
     <Name>CQtDeployer</Name>
-    <Version>1.5.2.3</Version>
+    <Version>1.5.2.4</Version>
     <Title>CQtDeployer</Title>
     <Publisher>QuasarApp</Publisher>
     <StartMenuDir>CQtDeployer</StartMenuDir>
diff --git a/QIFData/config/configWin.xml b/QIFData/config/configWin.xml
index 1f67fd8..299bc4c 100644
--- a/QIFData/config/configWin.xml
+++ b/QIFData/config/configWin.xml
@@ -3,7 +3,7 @@
     <WizardDefaultWidth>640px</WizardDefaultWidth>
     <WizardDefaultHeight>400px</WizardDefaultHeight>
     <Name>CQtDeployer</Name>
-    <Version>1.5.2.3</Version>
+    <Version>1.5.2.4</Version>
     <Title>CQtDeployer</Title>
     <Publisher>QuasarApp</Publisher>
     <StartMenuDir>CQtDeployer</StartMenuDir>
diff --git a/QIFData/installerCQtDeployer.pri b/QIFData/installerCQtDeployer.pri
index 1d5690b..855c2ed 100644
--- a/QIFData/installerCQtDeployer.pri
+++ b/QIFData/installerCQtDeployer.pri
@@ -20,7 +20,7 @@ BASE_DEPLOY_FLAGS_CQT = $$BASE_DEPLOY_FLAGS -targetDir $$DATA_DIR $$OUT_LIB $$OU
 
 win32:CQT_ICON = -icon $$PWD/config/icon.ico
 unix:CQT_ICON = -icon $$PWD/config/logo.png
-BASE_DEPLOY_FLAGS_DEB = $$BASE_DEPLOY_FLAGS -targetDir $$PWD/../Distro $$OUT_LIB $$OUT_BIN deb zip -name CQtDeployer -publisher QuasarApp $$CQT_ICON -deployVersion 1.5.2.3
+BASE_DEPLOY_FLAGS_DEB = $$BASE_DEPLOY_FLAGS -targetDir $$PWD/../Distro $$OUT_LIB $$OUT_BIN deb zip -name CQtDeployer -publisher QuasarApp $$CQT_ICON -deployVersion 1.5.2.4
 
 DEPLOY_TARGET_DEB = $$DEPLOY_TARGET,$$PWD/packages/QIF/data/QIF
 deploy_dep.commands += $$DEPLOYER -bin $$DEPLOY_TARGET $$BASE_DEPLOY_FLAGS_CQT
diff --git a/QIFData/packages/cqtdeployer.1_5/meta/package.xml b/QIFData/packages/cqtdeployer.1_5/meta/package.xml
index 812f9f3..ddf5ecc 100644
--- a/QIFData/packages/cqtdeployer.1_5/meta/package.xml
+++ b/QIFData/packages/cqtdeployer.1_5/meta/package.xml
@@ -2,7 +2,7 @@
 <Package>
     <DisplayName>CQtDeployer 1.5</DisplayName>
     <Description>CQtDeployer 1.5</Description>
-    <Version>1.5.2.3</Version>
+    <Version>1.5.2.4</Version>
     <Default>true</Default>
     <ForcedInstallation>false</ForcedInstallation>
     <Script>installscript.js</Script>
diff --git a/snap/gui/cqtdeployer.desktop b/snap/gui/cqtdeployer.desktop
index aeee91a..7348e02 100755
--- a/snap/gui/cqtdeployer.desktop
+++ b/snap/gui/cqtdeployer.desktop
@@ -1,5 +1,5 @@
 [Desktop Entry]
-Version=1.5.2.3
+Version=1.5.2.4
 Name=CQtDeployer
 Comment=CQtDeployer Help.
 Exec=cqtdeployer
@@ -10,6 +10,6 @@ Categories=Application;
 X-GNOME-Bugzilla-Bugzilla=GNOME
 X-GNOME-Bugzilla-Product=CQtDeployer
 X-GNOME-Bugzilla-Component=General
-X-GNOME-Bugzilla-Version=1.5.2.3
+X-GNOME-Bugzilla-Version=1.5.2.4
 StartupNotify=true
 Name[ru_RU]=CQtDeployer
diff --git a/snap/snapcraft.yaml b/snap/snapcraft.yaml
index 975f58d..caa39eb 100644
--- a/snap/snapcraft.yaml
+++ b/snap/snapcraft.yaml
@@ -6,7 +6,7 @@
 #
 
 name: cqtdeployer # you probably want to 'snapcraft register <name>'
-version: '1.5.2.3' # just for humans, typically '1.2+git' or '1.3.2'
+version: '1.5.2.4' # just for humans, typically '1.2+git' or '1.3.2'
 summary: deploy your qt projects # 79 char long summary
 description: |
   Console app for deploy qt libs.
diff --git a/Deploy/deploycore.h b/Deploy/deploycore.h
index b963096..2628091 100644
--- a/Deploy/deploycore.h
+++ b/Deploy/deploycore.h
@@ -296,11 +296,11 @@ public:
     static void printInternalError(const char *function, const char* file, int line);
 
     /**
      * @brief findFile This method search input file in prefixes and return absolute path to the found file. If file is not exists the return empty string.
      * @param file This is file path. If the file path si absalute path then return @a file value.
      * @return file info of the found file.
      */
-    static QFileInfo findFile(const QString &file);
+    static QFileInfo findItem(const QString &file);
 
 };
 
@@ -296,11 +296,11 @@ public:
 
     /**
-     * @brief findFile This method search input file in prefixes and return absolute path to the found file. If file is not exists the return empty string.
+     * @brief findItem This method search input file in prefixes and return absolute path to the found file. If file is not exists the return empty string.
      * @param file This is file path. If the file path si absalute path then return @a file value.
      * @return file info of the found file.